@@ -16,7 +16,6 @@ from fields import Namespace
 from process_tests import TestProcess as _TestProcess
 from process_tests import dump_on_error
 from process_tests import wait_for_strings
-from six import exec_
 
 import pytest_cov.plugin
 
@@ -498,10 +497,6 @@ def test_central_coveragerc(testdir, prop):
         'test_central_coveragerc* %s *' % prop.result,
         '*10 passed*',
     ])
-
-    # single-module coverage report
-    assert all(not line.startswith('TOTAL ') for line in result.stdout.lines[-4:])
-
     assert result.ret == 0
 
 
@@ -536,10 +531,6 @@ parallel = true
         'src[\\/]mod* %s *' % prop.result,
         '*10 passed*',
     ])
-
-    # single-module coverage report
-    assert all(not line.startswith('TOTAL ') for line in result.stdout.lines[-4:])
-
     assert result.ret == 0
 
 
@@ -642,9 +633,6 @@ show_missing = true
         '*10 passed*',
     ])
 
-    # single-module coverage report
-    assert all(not line.startswith('TOTAL ') for line in result.stdout.lines[-4:])
-
     assert result.ret == 0
 
 
@@ -791,13 +779,13 @@ def test_dist_not_collocated_coveragerc_source(testdir, prop):
     dir2 = testdir.mkdir('dir2')
     testdir.tmpdir.join('.coveragerc').write('''
 [run]
-%s
-source = %s
+{}
+source = {}
 [paths]
 source =
     .
     dir1
-    dir2''' % (prop.conf, script.dirpath()))
+    dir2'''.format(prop.conf, script.dirpath()))
 
     result = testdir.runpytest('-v',
                                '--cov',
@@ -1059,7 +1047,7 @@ def test_funcarg_not_active(testdir):
 @pytest.mark.skipif("sys.version_info[0] < 3", reason="no context manager api on Python 2")
 @pytest.mark.skipif('sys.platform == "win32"', reason="multiprocessing support is broken on Windows")
 @pytest.mark.skipif('platform.python_implementation() == "PyPy"', reason="often deadlocks on PyPy")
-@pytest.mark.skipif('sys.version_info[:2] == (3, 8)', reason="deadlocks on Python 3.8, see: https://bugs.python.org/issue38227")
+@pytest.mark.skipif('sys.version_info[:2] >= (3, 8)', reason="deadlocks on Python 3.8+, see: https://bugs.python.org/issue38227")
 def test_multiprocessing_pool(testdir):
     pytest.importorskip('multiprocessing.util')
 
@@ -1100,7 +1088,7 @@ def test_run_target():
 
 @pytest.mark.skipif('sys.platform == "win32"', reason="multiprocessing support is broken on Windows")
 @pytest.mark.skipif('platform.python_implementation() == "PyPy"', reason="often deadlocks on PyPy")
-@pytest.mark.skipif('sys.version_info[:2] == (3, 8)', reason="deadlocks on Python 3.8, see: https://bugs.python.org/issue38227")
+@pytest.mark.skipif('sys.version_info[:2] >= (3, 8)', reason="deadlocks on Python 3.8, see: https://bugs.python.org/issue38227")
 def test_multiprocessing_pool_terminate(testdir):
     pytest.importorskip('multiprocessing.util')
 
@@ -1538,8 +1526,14 @@ def test_cover_looponfail(testdir, monkeypatch):
     testdir.makeconftest(CONFTEST)
     script = testdir.makepyfile(BASIC_TEST)
 
-    monkeypatch.setattr(testdir, 'run',
-                        lambda *args, **kwargs: _TestProcess(*map(str, args)))
+    def mock_run(*args, **kwargs):
+        return _TestProcess(*map(str, args))
+
+    monkeypatch.setattr(testdir, 'run', mock_run)
+    assert testdir.run is mock_run
+    if hasattr(testdir, '_pytester'):
+        monkeypatch.setattr(testdir._pytester, 'run', mock_run)
+        assert testdir._pytester.run is mock_run
     with testdir.runpytest('-v',
                            '--cov=%s' % script.dirpath(),
                            '--looponfail',
@@ -1969,7 +1963,7 @@ def test_pth_failure(monkeypatch):
     monkeypatch.setattr(embed, 'init', bad_init)
     monkeypatch.setattr(sys, 'stderr', buff)
     monkeypatch.setitem(os.environ, 'COV_CORE_SOURCE', 'foobar')
-    exec_(payload)
+    exec(payload)
     assert buff.getvalue() == '''pytest-cov: Failed to setup subprocess coverage. Environ: {'COV_CORE_SOURCE': 'foobar'} Exception: SpecificError()
 '''
 
@@ -2004,6 +1998,33 @@ def test_double_cov2(testdir):
     assert result.ret == 0
 
 
+def test_cov_reset(testdir):
+    script = testdir.makepyfile(SCRIPT_SIMPLE)
+    result = testdir.runpytest('-v',
+                               '--assert=plain',
+                               '--cov=%s' % script.dirpath(),
+                               '--cov-reset',
+                               script)
+
+    assert 'coverage: platform' not in result.stdout.str()
+
+
+def test_cov_reset_then_set(testdir):
+    script = testdir.makepyfile(SCRIPT_SIMPLE)
+    result = testdir.runpytest('-v',
+                               '--assert=plain',
+                               '--cov=%s' % script.dirpath(),
+                               '--cov-reset',
+                               '--cov=%s' % script.dirpath(),
+                               script)
+
+    result.stdout.fnmatch_lines([
+        '*- coverage: platform *, python * -*',
+        'test_cov_reset_then_set* %s*' % SCRIPT_SIMPLE_RESULT,
+        '*1 passed*'
+    ])
+
+
 @pytest.mark.skipif('sys.platform == "win32" and platform.python_implementation() == "PyPy"')
 def test_cov_and_no_cov(testdir):
     script = testdir.makepyfile(SCRIPT_SIMPLE)
@@ -2092,7 +2113,7 @@ def test_contexts(testdir, opts):
             continue
         data.set_query_context(context)
         actual = set(data.lines(test_context_path))
-        assert line_data[label] == actual, "Wrong lines for context {!r}".format(context)
+        assert line_data[label] == actual, f"Wrong lines for context {context!r}"
 
 
 @pytest.mark.skipif("coverage.version_info >= (5, 0)")
